==> millennium-5.x-1.3.tar.gz: millennium/millennium.js <==
// $Id: millennium.js,v 1.1.2.3 2008/05/14 20:23:02 janusman Exp $

// Fire startup event
$(document).ready(millenniumUpdateNext);

/**
 * Looks for first div element with class "load" and updates it depending on its id attribute
 * (DIVs should already have an id="nid-XXXX" attribute, where XXXX is the node's id
 */
function millenniumUpdateNext() {
  // Get the first div element with the classes we are looking for
  var div = $("div.holdings.load").get(0);
  if (! div) return;
  var id = div.id;
  if (! id || id.substr(0,4) != "nid-" ) return;
  
  // Get the node id from the id attribute
  var nid = id.substr(4); //nid-123456 --> 123456
  
  /**
   * URL to get information from. If you go here in your browser you get plain HTML depending on the nid argument. This URL is defined in the module under millennium_menu()
   */
  var url = "?q=millennium_ajax&nid=" + nid;
  
  // Show 'loading' message.
  //$("#"+id).hide(); // Hide
  div.innerHTML = '<img src=/' + millenniumModulePath + '/throbber.gif />' + millenniumLoadingText;
  $("#"+id).addClass("loading");
  
  // Activate the ajax information fetch from "url". When done function(data) will get executed.
  $.get(url, function(data) { 
      //$("#"+id).slideUp("fast"); // Hide
      $("#"+id).removeClass("loading");
      $("#"+id).html(data); // Replace 'loading' message with fetched HTML
      $("#"+id).slideDown("slow");  // Un-hide it
      $("#"+id).removeClass("load"); // Now, "unmark" it so millenniumUpdateNext() skips this element 
      millenniumUpdateNext(); // Start over for another element
    } 
  );
}

==> millennium-5.x-1.4.tar.gz: millennium/millennium.js <==
// $Id: millennium.js,v 1.1.2.4 2008/06/18 21:48:43 janusman Exp $

// Fire startup event
$(document).ready(millenniumUpdateNext);

/**
 * Looks for first div element with class "load" and updates it depending on its id attribute
 * (DIVs should already have an id="nid-XXXX" attribute, where XXXX is the node's id
 */
function millenniumUpdateNext() {
  // Get the first div element with the classes we are looking for
  var div = $("div.holdings.load").get(0);
  if (! div) return;
  var id = div.id;
  if (! id || id.substr(0,4) != "nid-" ) return;
  
  // Get the node id from the id attribute
  var nid = id.substr(4); //nid-123456 --> 123456
  
  /**
   * URL to get information from. If you go here in your browser you get plain HTML 
   * depending on the nid argument. This URL is defined in the module under millennium_menu()
   */
  var url = "?q=millennium_ajax&nid=" + nid + "&locale=" + millenniumLocale;
  
  // Show 'loading' message.
  //$("#"+id).hide(); // Hide
  div.innerHTML = '<img src=/' + millenniumModulePath + '/throbber.gif />' + millenniumLoadingText;
  $("#"+id).addClass("loading");
  
  // Activate the ajax information fetch from "url". When done function(data) will get executed.
  $.get(url, function(data) { 
      //$("#"+id).slideUp("fast"); // Hide
      $("#"+id).removeClass("loading");
      $("#"+id).html(data); // Replace 'loading' message with fetched HTML
      $("#"+id).slideDown("slow");  // Un-hide it
      $("#"+id).removeClass("load"); // Now, "unmark" it so millenniumUpdateNext() skips this element 
      millenniumUpdateNext(); // Start over for another element
    } 
  );
}
